@@ -17,7 +17,6 @@ import errno
 import glob
 import io
 import os
-import re
 import shutil
 import subprocess
 import tarfile
@@ -57,13 +56,9 @@ COLLECT_LOGS_COMMANDS = {
     'df': ['df', '-a'],
     'iptables': ['iptables', '-L'],
     'ip_addr': ['ip', 'addr'],
-    'lshw': ['lshw', '-quiet', '-json'],
 }
 
 
-PARTED_ESP_PATTERN = re.compile(r'^\s*(\d+)\s.*\s\s.*\s.*esp(,|\s|$).*$')
-
-
 def execute(*cmd, **kwargs):
     """Convenience wrapper around ironic_lib's execute() method.
 
@@ -81,9 +76,8 @@ def try_execute(*cmd, **kwargs):
     Instead of raising an exception on failure, this method simply
     returns None in case of failure.
 
-    :param *cmd: positional arguments to pass to processutils.execute()
-    :param log_stdout: keyword-only argument: whether to log the output
-    :param **kwargs: keyword arguments to pass to processutils.execute()
+    :param cmd: positional arguments to pass to processutils.execute()
+    :param kwargs: keyword arguments to pass to processutils.execute()
     :raises: UnknownArgumentError on receiving unknown arguments
     :returns: tuple of (stdout, stderr) or None in some error cases
     """
@@ -441,23 +435,3 @@ def get_ssl_client_options(conf):
     else:
         cert = None
     return verify, cert
-
-
-def get_efi_part_on_device(device):
-    """Looks for the efi partition on a given device
-
-    :param device: lock device upon which to check for the efi partition
-    :return: the efi partition or None
-    """
-    efi_part = None
-    out, _u = execute('parted', '-s', device, '--', 'print')
-    for line in out.splitlines():
-        m = PARTED_ESP_PATTERN.match(line)
-        if m:
-            efi_part = m.group(1)
-
-            LOG.debug("Found efi partition %s on device %s.", efi_part, device)
-            break
-    else:
-        LOG.debug("No efi partition found on device %s", device)
-    return efi_part
